Coverage for appr/formats/appr/kpm.py: 88%

# Coverage for appr/formats/appr/kpm.py : 88%

## 8 statements 7 run 1 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 | from __future__ import absolute_import, division, print_function from appr.formats.appr.kub import Kub class Kpm(Kub): media_type = 'kpm' platform = "kubernetes" manifest_file = ['manifest.jsonnet', 'manifest.yaml', 'manifest.yml', 'kpm-manifest.jsonnet'] @property def kubClass(self): return Kpm